#!/bin/bash
# Some files are install(copy) by dh_install tool(see rules and espr.install files)
#This script complete the installation process:
#	4-Update path for training configuration files

#-----------------------------------
# Define variables
#-----------------------------------
#PATH
DEBdir=$SRCdir/debian/espr-validation$ESPdir
# see export in rules file
#path for local binary
export PATH="/usr/esru/esp-r/bin:$PATH"
BPS="bps"
CLM="clm"
ISH="ish"
PRJ="prj"
PDB="pbd"
skip_ish_calcs="no"        # Skip update of exemplar shading files?
reuse_ish_calcs="no"       # if yes limit re-calculation of exemplar shading files?

#-----------------------------------
# Copy validation files
#-----------------------------------
echo -n "   - Copying validation models..."
cd ${SRCdir}/validation/CEN/13791/databases
$CLM -mode text -file Cond.clm -act asci2bin silent Cond.clm.a >/dev/null
$CLM -mode text -file WM_A.clm -act asci2bin silent WM_A.clm.a >/dev/null
$CLM -mode text -file WM_B.clm -act asci2bin silent WM_B.clm.a >/dev/null
cp -r $SRCdir/validation/* $DEBdir/validation/
find  $DEBdir/validation -name "\.svn" | xargs rm -fr
#Change path in list files
sed -e 's|/usr/esru/esp-r|'"$ESPdir"'|' $SRCdir/validation/stds_list > $DEBdir/validation/stds_list
#Removing binary database from training models ...
     cd ${SRCdir}/
     rm -f validation/CEN/13791/databases/WM_A.clm
     rm -f validation/CEN/13791/databases/WM_B.clm
     rm -f validation/CEN/13791/databases/Cond.clm


#-----------------------------------
# Update directory names in training models to reflect DESTdir
# Scan training and validation folders for configuration files.
#-----------------------------------

cd ${SRCdir}
 echo "   - Updating model shading and database records..."
 #copy *.shda (ascii file) to *.shd (which are converted ascii to binary by ish thereafter)
 find ./validation -name *.shda -print | while read i; do cp $i ${i%.*}.shd; done
  cfgnames=(`find  ./validation -name "*.cfg" -print`)
  # Count cfg files
  cfgcount=`find ./validation -name "*.cfg" -print | wc -l`
  # For each cfg file check for shading dbs
  cfgnum=0
  for file in "${cfgnames[@]}"; do
    cfgnum=$((${cfgnum} + 1))
    printf "      -> model ${cfgnum}/${cfgcount} (${file})"                                   
    # Create a list of zone ref numbers and isi files in this cfg file
    if [ "${skip_ish_calcs}" = "no" ]; then
      isi=(`egrep '(\*isi\ |\*zon\ )' $file | cut -d# -f1`)
      # Count zones with shading
      ish_tag_count=(`egrep '(\*isi\ )' $file | cut -d# -f1 | wc -l `)
      hits=${#isi[@]}
      i=0
      # Get the zone number and check if there is a isi file associated 
      # with this zone.  The format of the isi variable is 
      # "*zon  1  *zon  2  *isi  ../zones/xx.shd" and so on where hits 
      # is the number of words in the list isi.
      ish_processed_count=0
      while [ $((i)) -lt $((hits-2)) ]; do
      if [ ${isi[$((i))]} == "*zon" ]; then
    
        if [ ${isi[$((i+2))]} == "*isi" ]; then
          ish_processed_count=$((${ish_processed_count}+1))

          if [ "${reuse_ish_calcs}" = "no" ]; then
            printf "\r      -> model ${cfgnum}/${cfgcount} (${file}); zone ${ish_processed_count}/${ish_tag_count}"
            $ISH -mode text -file ${file:2} -zone ${isi[$((i+1))]} -act update_silent > /dev/null
            shdfile=${file%/*}/${isi[$((i+3))]}
            mv -f ${shdfile} $DEBdir/${shdfile}
          elif [ "${reuse_ish_calcs}" = "yes" ]; then
            printf "\r      -> model ${cfgnum}/${cfgcount} (${file}); zone ${ish_processed_count}/${ish_tag_count}"
            $ISH -mode text -file ${file:2} -zone ${isi[$((i+1))]} -act useupdate_silent > /dev/null
            shdfile=${file%/*}/${isi[$((i+3))]}
            mv -f ${shdfile} $DEBdir/${shdfile}
          fi
        fi
      fi
      i=2+$(($i))
      done
    fi
    printf "\n"
    #
    # Now update the paths in models to reflect install dir.
    #
    # Note: This approach will not work for models with plant
    #       networks. ESP-r saves the plant database path in
    #       two locations: a) in the .cfg file, and in the
    #       .pln file. prj uses the record in the .cfg file,
    #       while bps references the record in the .pln file.
    #       Thus training models containing plant networks will
    #       bre browsable, but will not run.
    #
    #       This code should either be updated to edit the .pln
    #       file as well, or (preferably) bps should be updated
    #       to reference the plant database record in the cfg
    #       file. 
    #
    sed -e 's|/usr/esru/esp-r|'"${ESPdir}"'|' ${file} > $DEBdir/${file:2}
  done
  echo "     Done."

